<?php
/**
 * Plugin redacteur restreint
 * Copyright (c) Christophe IMBERTI
 * Licence Creative commons by-nc-sa
 */

if (!defined("_ECRIRE_INC_VERSION")) return;

include_spip('inc/filtres');

/**
 * Modifier la clause where
 *
 * @param array $boucle
 * @return array
 */
// function cirr_pre_boucle(&$boucle){
function cirr_pre_boucle($boucle){
	if (test_espace_prive() OR cirr_test_cisf()) {
		$securise = false;
		
		switch ($boucle->type_requete){
			case 'hierarchie':
			case 'rubriques':
			case 'articles':
			case 'breves':
			case 'sites':
			case 'syndication':
				$t = $boucle->id_table . '.id_rubrique';
				$boucle->select = array_merge($boucle->select, array($t)); // pour postgres
				$boucle->where[] = "array('OR',".cirr_where_auteur_non_restreint().",".cirr_rubriques_accessibles_where($t).")";
				$securise = true;
				break;
			case 'forums':
				$t = $boucle->id_table . '.id_objet';
				$objet = $boucle->id_table . '.objet';
				$boucle->select = array_merge($boucle->select, array($t)); // pour postgres
				$where_rubrique = "array('AND','".$objet."=\'rubrique\'',".cirr_rubriques_accessibles_where($t).")";
				$where_article = "array('AND','".$objet."=\'article\'',".cirr_articles_accessibles_where($t).")";
				$where = "array('OR',$where_rubrique,$where_article)";
				if (defined('_DIR_PLUGIN_BREVES')){
					$where_breve = "array('AND','".$objet."=\'breve\'',".cirr_breves_accessibles_where($t).")";
					$where = "array('OR',$where,$where_breve)";
				}
				$boucle->where[] = "array('OR',".cirr_where_auteur_non_restreint().",$where)";
				$securise = true;
				break;
			case 'versions':
				$t = $boucle->id_table . '.id_objet';
				$objet = $boucle->id_table . '.objet';
				$boucle->select = array_merge($boucle->select, array($t)); // pour postgres
				$where_rubrique = "array('AND','".$objet."=\'rubrique\'',".cirr_rubriques_accessibles_where($t).")";
				$where_article = "array('AND','".$objet."=\'article\'',".cirr_articles_accessibles_where($t).")";
				$where = "array('OR',$where_rubrique,$where_article)";
				if (defined('_DIR_PLUGIN_BREVES')){
					$where_breve = "array('AND','".$objet."=\'breve\'',".cirr_breves_accessibles_where($t).")";
					$where = "array('OR',$where,$where_breve)";
				}
				$boucle->where[] = "array('OR',".cirr_where_auteur_non_restreint().",$where)";
				$securise = true;
				break;
			case 'evenements':
				$t = $boucle->id_table . '.id_article';
				$boucle->select = array_merge($boucle->select, array($t)); // pour postgres
				$boucle->where[] = "array('OR',".cirr_where_auteur_non_restreint().",".cirr_articles_accessibles_where($t).")";
				$securise = true;
				break;
			case 'petitions':
				$t = $boucle->id_table . '.id_article';
				$boucle->select = array_merge($boucle->select, array($t)); // pour postgres
				$boucle->where[] = "array('OR',".cirr_where_auteur_non_restreint().",".cirr_articles_accessibles_where($t).")";
				$securise = true;
				break;
			case 'signatures':
				$securise = true;
				break;
			case 'syndic_articles':
//				$t = $boucle->id_table . '.' . $boucle->primary;
				$t = $boucle->id_table . '.id_syndic';
				$boucle->select = array_merge($boucle->select, array($t)); // pour postgres
				$boucle->where[] = "array('OR',".cirr_where_auteur_non_restreint().",".cirr_syndic_articles_accessibles_where($t).")";
				$securise = true;
				break;
			case 'documents':
				$t = $boucle->id_table . '.' . $boucle->primary;
				$boucle->select = array_merge($boucle->select, array($t)); // pour postgres
				$boucle->where[] = "array('OR',".cirr_where_auteur_non_restreint().",".cirr_documents_accessibles_where($t).")";
				$securise = true;
				break;
		}

		if ($securise){
			$boucle->hash .= "if (!defined('_DIR_PLUGIN_CIRR')){
			\$link_empty = generer_url_ecrire('admin_vider'); \$link_plugin = generer_url_ecrire('admin_plugin');
			\$message_fr = 'Le plugin CIRR a ete desactivé. Vider le cache.';
			\$message_en = 'Plugin CIRR is now unusable. Empty the cache.';
			die(\$message_fr.'<br />'.\$message_en);
			}";
		}
			
	}
	return $boucle;
}


/**
 * Auteur non restreint
 */
function cirr_where_auteur_non_restreint($_publique=''){
	return "cirr_auteur_non_restreint()";
}

 
/**
 * Renvoyer le code de la condition where pour la liste des rubriques accessibles
 *
 * @param string $primary
 * @return string
 */
function cirr_rubriques_accessibles_where($primary,$not='', $_publique=''){
	return "sql_in('$primary', cirr_tableau_rubriques_auteur(), '$not')";
}

/**
 * Renvoyer la condition where pour la liste des articles accessibles
 *
 * @param string $primary
 * @return string
 */
function cirr_articles_accessibles_where($primary, $_publique=''){
	# hack : on utilise zzz pour eviter que l'optimiseur ne confonde avec un morceau de la requete principale
	return "array('IN','$primary','('.sql_get_select('zzza.id_article','spip_articles as zzza',".cirr_rubriques_accessibles_where('zzza.id_rubrique','',$_publique).",'','','','',\$connect).')')";
}

/**
 * Renvoyer la condition where pour la liste des breves accessibles
 *
 * @param string $primary
 * @return string
 */
function cirr_breves_accessibles_where($primary, $_publique=''){
	# hack : on utilise zzz pour eviter que l'optimiseur ne confonde avec un morceau de la requete principale
	return "array('IN','$primary','('.sql_get_select('zzzb.id_breve','spip_breves as zzzb',".cirr_rubriques_accessibles_where('zzzb.id_rubrique','',$_publique).",'','','','',\$connect).')')";
}

/**
 * Renvoyer le code de la condition where pour la liste des syndic articles accessibles
 *
 * @param string $primary
 * @return string
 */
function cirr_syndic_articles_accessibles_where($primary, $_publique=''){
	# hack : on utilise zzz pour eviter que l'optimiseur ne confonde avec un morceau de la requete principale
	return "array('IN','$primary','('.sql_get_select('zzzs.id_syndic','spip_syndic as zzzs',".cirr_rubriques_accessibles_where('zzzs.id_rubrique','',$_publique).",'','','','',\$connect).')')";
	#return "array('IN','$primary',array('SUBSELECT','id_syndic','spip_syndic',array(".cirr_rubriques_accessibles_where('id_rubrique').")))";
}


/**
 * Renvoyer le code de la condition where pour la liste des forums accessibles
 * on ne rend visible que les forums qui sont lies a un article, une breve ou une rubrique visible
 *
 * @param string $primary
 * @return string
 */
function cirr_forums_accessibles_where($primary, $_publique=''){
        # hack : on utilise zzz pour eviter que l'optimiseur ne confonde avec un morceau de la requete principale
        $where_rubrique = "array('AND','zzzf.objet=\'rubrique\'',".cirr_rubriques_accessibles_where('zzzf.id_objet','NOT',$_publique).")";
        $where_article = "array('AND','zzzf.objet=\'article\'',".cirr_articles_accessibles_where('zzzf.id_objet',$_publique).")";
        if (defined('_DIR_PLUGIN_BREVES'))
                $where_breve = "array('AND','zzzf.objet=\'breve\'',".cirr_breves_accessibles_where('zzzf.id_objet',$_publique).")";

	$where = "array('OR',$where_rubrique,$where_article)";
	$where = "array('OR',$where,$where_breve)";

	return "array('IN','$primary','('.sql_get_select('zzzf.id_forum','spip_forum as zzzf',array($where),'','','','',\$connect).')')";

}


/**
 * Renvoyer le code de la condition where pour la liste des documents accessibles
 * on ne rend visible que les docs qui sont lies a un article, une breve ou une rubrique visible
 *
 * @param string $primary
 * @return string
 */
function cirr_documents_accessibles_where($primary, $_publique=''){	
	# hack : on utilise zzz pour eviter que l'optimiseur ne confonde avec un morceau de la requete principale
	$where = "array('AND','zzzd.objet=\'article\'',".cirr_articles_accessibles_where('zzzd.id_objet',$_publique).")";

        $ci_doc_rubriques = false;
        if (isset($GLOBALS['meta']["documents_objets"]) AND in_array('spip_rubriques',explode(',',$GLOBALS['meta']["documents_objets"]))){
            $ci_doc_rubriques = true;
        }
        
	if ($ci_doc_rubriques) {
		$where = "array('OR',$where,array('AND','zzzd.objet=\'rubrique\'',".cirr_rubriques_accessibles_where('zzzd.id_objet','',$_publique)."))";
	}
	
	if (defined('_DIR_PLUGIN_BREVES') OR ($GLOBALS['spip_version_branche']<3 AND $GLOBALS['meta']['activer_breves']=='oui')){
		$where = "array('OR',$where,array('AND','zzzd.objet=\'breve\'',".cirr_breves_accessibles_where('zzzd.id_objet',$_publique)."))";
	}
	$where = "array('IN','$primary','('.sql_get_select('zzzd.id_document','spip_documents_liens as zzzd',array($where),'','','','',\$connect).')')";

	return $where;
}


/**
 * Apres insertion en base d'un lien d'un document,
 * verifier qu'on la droit de modifier l'objet cible ET de modifier le document (sauf s'il est publie)
 *
 * @param array $x   Donnees du pipeline
 * @return int $id_objet
 */
function cirr_post_edition_lien($x) {
		$id_document = intval($x['args']['id_objet_source']);
	
		if ($x['args']['action']=='insert' AND $x['args']['objet_source']=='document' AND $id_document>0 
			 AND $x['args']['objet'] AND intval($x['args']['id_objet'])>0) {
	
                         // Il faut laisser la possibilite d'ajouter des documents dans un forum
                         if (in_array($x['args']['objet'],array('article','rubrique','auteur','site','breve'))){
                                // verifier qu'on la droit de modifier l'objet cible (important)
                                if (!autoriser('modifier', $x['args']['objet'], intval($x['args']['id_objet']))){
                                        cirr_delete_document_lien($x['args']);
                                }

                                // compatibilite avec CIAR
                                elseif (defined('_DIR_PLUGIN_CIAR')){
                                        include_spip('inc/ciar_fonctions');
                                        if (ciar_document_autre_parent_protege($id_document,$x['args']['objet'], intval($x['args']['id_objet']))){
                                                cirr_delete_document_lien($x['args']);
                                        }
                                }

                                if (defined('_CIRR_ANTI_HACK') AND _CIRR_ANTI_HACK=='oui'){	

                                        // document publie ?
                                        $row = sql_fetsel("statut", "spip_documents", "id_document=$id_document");
                                        if ($row)
                                                $statut = $row['statut'];
                                        else
                                                $statut = '';

                                        // verifier que le document est publie ou qu'on la droit de modifier le document
                                        if ($statut!='publie' AND !autoriser('modifier', $x['args']['objet_source'], $id_document))
                                                cirr_delete_document_lien($x['args']);
                                }
                         }
		}
}

function cirr_delete_document_lien($args){
	sql_delete("spip_documents_liens", "id_document=".intval($args['id_objet_source'])." AND id_objet=".intval($args['id_objet'])." AND objet=".sql_quote($args['objet']));
}

/**
 * Protection simple
 * Avant l'enregistrement d'un article ou d'une rubrique, verifier que les raccourcis <doc...>, etc
 * qu'il contient ne correspondent pas a une piece jointe d'un article non publie qu'on n'a pas le droit de voir
 *
 * @param array $flux
 * @return array
 */
function cirr_pre_edition($flux){
    if (!defined('_DIR_PLUGIN_CIAR')){
        if (defined('_CIRR_ANTI_HACK') AND _CIRR_ANTI_HACK=='oui' AND isset($flux['args']['table'])){	
            $champs = array();
            if ($flux['args']['table']=='spip_articles'){
                $champs = array('surtitre', 'titre', 'soustitre', 'descriptif', 'nom_site', 'url_site', 'chapo', 'texte', 'ps');
            } elseif ($flux['args']['table']=='spip_rubriques'){
                $champs = array('titre', 'texte', 'descriptif');
            } elseif ($flux['args']['table']=='spip_forum'){
                $champs = array('titre', 'texte');
            }
            
            if ($champs) {
                foreach ($champs as $champ) {
                    if (isset($flux['data'][$champ]) AND $flux['data'][$champ]){
                        $flux['data'][$champ] = cirr_anti_scan_pj($flux['data'][$champ],$flux['args']['table'].$flux['args']['id_objet'].$champ);
                    }
                }
            }
        }
    }

    return $flux;
}


/**
 * Anti scan de document via <doc...>, etc
 *
 * @param string $texte
 * @return string
 */
function cirr_anti_scan_pj($texte,$id=0){
	// contourner le cas d'un double appel du pipeline sur la meme table
	static $tableau = array();

        $ok = true;
        // exception pour CISF
        if (isset($_POST['cisf_nostatic']) AND $_POST['cisf_nostatic'] == "oui")
            $ok = false;
        
	if ($id){
		if ($tableau AND isset($tableau[$id]) AND $ok){
			return $tableau[$id];
		} else {
			if (!empty($texte) AND preg_match_all(',<([a-z]+)([0-9]+)(\|([^>]*))?'.'\s*/?'.'>,i', $texte, $matches, PREG_SET_ORDER)) {
				foreach ($matches as $match) {
					$raccourci = $match[0];
					$id_document = intval($match[2]);
                                        $modele = $match[1];
                                        if (in_array($modele,array('doc','img','emb','video','audio','image','infographie'))){
                                                $s = sql_getfetsel("statut", "spip_documents", "id_document=".$id_document);
                                                if (!$s OR $s!=='publie'){
                                                        if (!autoriser('modifier', 'document', $id_document)){
                                                                        $texte = str_replace($raccourci,'',$texte);
                                                        }
                                                }
                                        }
				}
			}
			$tableau[$id] = $texte;
		}
	}

	return $texte;
}

function cirr_test_cisf(){
	$return = false;

	if (defined('_DIR_PLUGIN_CISF')) {
		if (_request('page')=='cisf_choix_document')
			$return = true;
	}

	return $return;
}

?>