<?php

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}


/**
 * Dissocier un widget
 *
 * @param string $arg
 *     fournit les arguments de la fonction dissocier_ciwidget
 *     sous la forme `$id_objet-$objet-$id_widget-suppr-safe`
 *
 *     - 4eme arg : suppr = true, false sinon
 *     - 5eme arg : safe = true, false sinon
 *
 * @return void
 */
function action_dissocier_ciwidget_dist($arg = null) {
    if (is_null($arg)) {
        $securiser_action = charger_fonction('securiser_action', 'inc');
        $arg = $securiser_action();
    }

    // attention au cas ou id_objet est negatif !
    if (strncmp($arg, '-', 1) == 0) {
        $arg = explode('-', substr($arg, 1));
        list($id_objet, $objet, $id_widget) = $arg;
        $id_objet = -$id_objet;
    } else {
        $arg = explode('-', $arg);
        list($id_objet, $objet, $id_widget) = $arg;
    }

    $suppr = $check = false;
    if (count($arg) > 3 and $arg[3] == 'suppr') {
        $suppr = true;
    }
    if (count($arg) > 4 and $arg[4] == 'safe') {
        $check = true;
    }
    if ($id_objet = intval($id_objet)
            and (
                ($id_objet < 0 and $id_objet == -$GLOBALS['visiteur_session']['id_auteur'])
                or autoriser('dissocierciwidgets', $objet, $id_objet)
            )
    ) {
        dissocier_ciwidget($id_widget, $objet, $id_objet, $suppr, $check);
    } else {
        spip_log("Interdit de modifier $objet $id_objet", 'spip');
    }
}

/**
 * Dissocier un ou des widgets
 *
 * @param int $id_widget
 *   id_widget a dissocier
 * @param string $objet
 *   objet duquel dissocier
 * @param  $id_objet
 *   id_objet duquel dissocier
 * @param bool $supprime
 *   supprimer les widgets orphelins apres dissociation
 * @param bool $check
 *   verifier le texte des widgets et relier les widgets references dans l'objet
 * @return void
 */
function dissocier_ciwidget($id_widget, $objet, $id_objet, $supprime = false, $check = false) {
    $id_widget = intval($id_widget);
    $id_objet = intval($id_objet);
    $type_widget = '';
    $titre_widget = '';
    $citrace = '';
    $citrace_ok = false;
    $id_rubrique = '';

    if ($id_widget AND $objet AND $id_objet) {

        if ($check) {
            // si demande, on verifie que ses widgets vus sont bien lies !
            $spip_table_objet = table_objet_sql($objet);
            $table_objet = table_objet($objet);
            $id_table_objet = id_table_objet($objet);
            if (!empty($id_table_objet)){
                $champs = sql_fetsel('*', $spip_table_objet, addslashes($id_table_objet) . '=' . intval($id_objet));

                $marquer_doublons_doc = charger_fonction('marquer_doublons_widget', 'inc');
                $marquer_doublons_doc($champs, $id_objet, $objet, $id_table_objet, $table_objet, $spip_table_objet, '', '');
            }
        }

        if ($supprime) {

            $res = sql_select('*','spip_ciwidget', "id_widget=".$id_widget);
            while ($row = sql_fetch($res)) {
                $type_widget = $row['type_widget'];
                $titre_widget = $row['titre'];
            }

            if (defined('_DIR_PLUGIN_CITRACE')){
                if ($citrace = charger_fonction('citrace', 'inc')) {
                    $citrace_ok = true;
                    
                    if ($objet=='rubrique'){
                        $id_rubrique = $id_objet;
                    } elseif ($objet=='article'){
                        $id_rubrique = sql_getfetsel('id_rubrique', 'spip_articles', "id_article = ". intval($id_objet));
                    }
                }
            }
            
            // Dissocier les doc associes au widget (puis les supprimer)
            $suppr_doc = false;
            $fichiers = array();
            $res = sql_select('id_document','spip_documents_liens', "objet='ciwidget' AND id_objet=".$id_widget);
            while ($row = sql_fetch($res)) {
                $id_document = intval($row['id_document']);
                $doc = sql_fetsel('fichier,id_vignette', 'spip_documents', 'id_document=' . $id_document);
                $fichiers[] = $doc['fichier'];
                sql_delete('spip_documents_liens', "id_document=".$id_document." AND objet='".$objet."' AND id_objet=".$id_objet);
                sql_delete('spip_documents', "id_document=".$id_document);

                // Si c'est un document ayant une vignette, supprimer aussi la vignette
                if ($doc['id_vignette']) {
                    $vignette = sql_fetsel('fichier', 'spip_documents', 'id_document=' . intval($doc['id_vignette']));
                    sql_delete('spip_documents', "id_document=".$doc['id_vignette']);
                    $fichiers[] = $vignette['fichier'];
                }

                foreach ($fichiers AS $fichier){
                    $fichier = (
                            strncmp($fichier, _DIR_IMG, strlen(_DIR_IMG)) != 0
                    )
                            ? _DIR_IMG . $fichier
                            : $fichier;
                    spip_unlink($fichier);
                    $suppr_doc = true;
                    
                    if ($citrace_ok) {
                        $message = '('.$fichier.') du widget '.$type_widget.' '.$id_widget.' ('.$titre_widget.') dans '.$objet.' '.$id_objet;				
                        $citrace('document', $id_document, 'supprimer document', $message, $id_rubrique);
                    }
                        
                }
            }
            if ($suppr_doc) {
                sql_delete('spip_documents_liens', "objet='ciwidget' AND id_objet=".$id_widget);
            }

            // Supprimer ensuite le widget
            sql_delete('spip_ciwidget', "id_widget=".$id_widget);
            
        }
    }

    return true;
}

?>