<?php
/**
 * Plugin CIWIDGET
 * Copyright (c) Christophe IMBERTI
 * Licence Creative commons by-nc-sa
 */

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

include_spip('inc/ciwidget_inc_meta');
include_spip('inc/cistyle_commun');
include_spip('inc/widget_commun');


function inc_ciwidget_style_config_fonc_dist($action='',$type_widget='',$element='',$id_style=''){
    if ($action=='valeurs_defaut'){
        return ciwidget_style_valeurs_defaut($type_widget,$element);
    } elseif ($action=='associer'){
        return ciwidget_style_associer($type_widget,$element,$id_style);        
    } elseif ($action=='dissocier'){
        return ciwidget_style_dissocier($type_widget,$element);
    } elseif ($action=='parametrage_par_fichier'){
        return ciwidget_style_parametrage_par_fichier($type_widget,$element,$id_style);        
    } else {
        return false;
    }
}

function ciwidget_style_valeurs_defaut($type_widget='',$element=''){
    $return = array();
    
    // Pour les valeurs par défaut, le nom des propriétés est préfixé par le nom de l'élément suivi d'un underscore 
    $prefixe = $element.'_';
    $longueur = strlen($prefixe);
    
    $tableau = ciwidget_lire_meta_widget($type_widget);
    $tableau_nom_des_proprietes = cistyle_tableau_nom_des_proprietes();
    
    // valeurs dans spip_meta
    foreach ($tableau AS $cle=>$valeur){
        if (substr($cle,0,$longueur)==$prefixe){
            if (in_array(substr($cle,$longueur),$tableau_nom_des_proprietes)){
                $cle_sans_prefixe = substr($cle,$longueur);
                $return[$cle_sans_prefixe] = $valeur;
            }
        }
    }

    if (!$return) {
        // valeurs par défaut
        $ciwidget_defaut = ciwidget_valeurs_par_defaut();
        if (isset($ciwidget_defaut[$widget])) {
            foreach ($ciwidget_defaut[$widget] AS $cle=>$valeur){
                if (substr($cle,0,$longueur)==$prefixe){
                    $cle_sans_prefixe = substr($cle,$longueur);
                    $return[$cle_sans_prefixe] = $valeur;
                }
            }
        }
    }
    
    return $return;
}

function ciwidget_style_associer($type_widget='',$element='',$id_style=''){
    $type_widget_config = array();
    $type_widget_defaut = array();
    $valeurs = array();
    $anciennes_proprietes = false;
    
    if ($id_style AND $type_widget AND $element){

        // config du type de widget dans spip_meta
        $ciwidget_config = ciwidget_lire_meta();
        if (isset($ciwidget_config[$type_widget])) {
            $type_widget_config = $ciwidget_config[$type_widget];
        }

        // valeurs par défaut du type de widget
        $ciwidget_defaut = ciwidget_valeurs_par_defaut();
        if (isset($ciwidget_defaut[$type_widget])) {
            $type_widget_defaut = $ciwidget_defaut[$type_widget];
        }

        // valeurs actuelles du type de widget dans spip_meta
        if (isset($ciwidget_config[$type_widget])) {
            $valeurs = $ciwidget_config[$type_widget];
        }

        // Enlever (le cas échéant) les anciennes propriétés mémorisées dans spip_meta
        $prefixe = $element.'_';
        $longueur = strlen($prefixe);
        foreach ($type_widget_defaut AS $nom_champ=>$valeur_defaut){
            if (substr($nom_champ,0,$longueur)==$prefixe){
                unset($valeurs[$nom_champ]);
                $anciennes_proprietes = true;
            }
        }

        if ($anciennes_proprietes){
            // memoriser
            ciwidget_ecrire_meta($type_widget,$valeurs);
            
            // purger la CSS en cache  
            ciwidget_purger_cache_css();
        }
    }
    
    return true;
}

function ciwidget_style_dissocier($type_widget='',$element=''){
    $valeurs = array();
    $anciennes_proprietes = false;
    
    if ($type_widget AND $element){

        // config du type de widget dans spip_meta
        $ciwidget_config = ciwidget_lire_meta();
        if (isset($ciwidget_config[$type_widget])) {
            $valeurs = $ciwidget_config[$type_widget];

            // compatibilite ascendante
            $element_et_suffixe = $element."_";
            $len_element_et_suffixe = strlen($element_et_suffixe);
            $ciwidget_defaut = ciwidget_valeurs_par_defaut();
            if (isset($ciwidget_defaut[$type_widget])) {
                foreach ($ciwidget_defaut[$type_widget] AS $nom_champ=>$valeur_defaut){
                    if (substr($nom_champ,0,$len_element_et_suffixe)==$element_et_suffixe){
                        if (isset($valeurs[$nom_champ])){
                            unset($valeurs[$nom_champ]);
                            $anciennes_proprietes = true;
                        }
                    }
                }
            }
        }
        
        if ($anciennes_proprietes){
            // memoriser
            ciwidget_ecrire_meta($type_widget,$valeurs);
            
            // purger la CSS en cache  
            ciwidget_purger_cache_css();
        }
    }
    
    return true;
}

function ciwidget_style_parametrage_par_fichier($type_widget='',$element='',$id_style=''){
    $return = false;
    
    if ($type_widget AND ciwidget_parametrage_widget_par_fichier($type_widget)) {
        $return = true;
    }

    return $return;
}      

?>