<?php
/**
 * Plugin CIWIDGET
 * Copyright (c) Christophe IMBERTI
 * Licence Creative commons by-nc-sa
 */

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

include_spip('inc/ciwidget_inc_meta');


function ciwidget_largeur($largeur='', $type_widget=''){
    $return = strval(intval($largeur));
    $ci_non_modifiable = ciwidget_lire_meta_cle($type_widget,'largeur_non_modifiable');
    $ci_defaut = ciwidget_lire_meta_cle($type_widget,'largeur_defaut');
    
    // compatibilite ascendante
    if ($type_widget=='graphique'){
        if (!$ci_defaut){
            $ci_defaut = ciwidget_lire_meta_cle($type_widget,'largeur');
        }
    }
    
    if ($type_widget AND $ci_non_modifiable=='oui' AND $ci_defaut){
        $return = strval(intval($ci_defaut));
    }
    if ($type_widget AND !$largeur AND $ci_defaut){
        $return = strval(intval($ci_defaut));
    }
    
    return $return;
}

function ciwidget_conversion_largeur($pourcentage='', $type_widget=''){
    $return = '500';
    
    if ($type_widget){
        $pourcentage = intval($pourcentage);
        $ci_defaut = intval(ciwidget_lire_meta_cle($type_widget,'largeur_defaut'));
        $ci_non_modifiable = ciwidget_lire_meta_cle($type_widget,'largeur_non_modifiable');

        // compatibilite ascendante
        if ($type_widget=='graphique'){
            if (!$ci_defaut){
                $ci_defaut = intval(ciwidget_lire_meta_cle($type_widget,'largeur'));
            }
        }
        
        if ($ci_non_modifiable=='oui' AND $ci_defaut){
            $return = strval($ci_defaut);
        } elseif ($pourcentage AND $pourcentage>0 AND $pourcentage<=100){
            $return = strval($ci_defaut*($pourcentage/100));
        } elseif ($ci_defaut){
            $return = strval($ci_defaut);
        }
    }
    return $return;
}

function ciwidget_hauteur($hauteur='', $type_widget=''){
    $return = strval(intval($hauteur));
    $ci_non_modifiable = ciwidget_lire_meta_cle($type_widget,'hauteur_non_modifiable');
    $ci_defaut = ciwidget_lire_meta_cle($type_widget,'hauteur_defaut');
    
    if ($type_widget AND $ci_non_modifiable=='oui' AND $ci_defaut){
        $return = strval(intval($ci_defaut));
    }
    if ($type_widget AND !$hauteur AND $ci_defaut){
        $return = strval(intval($ci_defaut));
    }
    
    return $return;
}

function ciwidget_aspect_ratio($aspect_ratio='', $type_widget=''){
    $return = strval(floatval($aspect_ratio));
    $ci_imposer_ratio_comme_maximum = ciwidget_lire_meta_cle($type_widget,'imposer_ratio_comme_maximum');
    $ci_defaut = ciwidget_lire_meta_cle($type_widget,'aspect_ratio');

    if ($type_widget){
        if ($aspect_ratio){
            if ($ci_imposer_ratio_comme_maximum=='oui' AND $ci_defaut){
                if (floatval($aspect_ratio) > floatval($ci_defaut)){
                    $return = strval(floatval($ci_defaut));
                }
            }
        } else {
            if ($ci_defaut){
                $return = strval(floatval($ci_defaut));
            }
        }
    }
    
    return $return;
}


function ciwidget_affichage_duree($duree) {
	$return = "";
        $duree = intval($duree);
	$heures = $minutes = $seconde = 0;
        
	if ($duree>3600) {
		$heures = intval(floor($duree/3600));
		$duree -= $heures * 3600;
	}
	if ($duree>60) {
		$minutes = intval(floor($duree/60));
		$duree -= $minutes * 60;
	}
        $seconde = $duree;

	if ($heures>0) {
		$return .= $heures. ' h';
	}
	if ($minutes>0) {
		if ($return) $return .= ' ';
		$return .= $minutes. ' min';
	}
	if ($seconde>0) {
		if ($return) $return .= ' ';
		$return .= $seconde.' s';
	}
	return $return;
}

function ciwidget_affichage_duree_deux_points($duree) {
	$return = "";
        $duree = intval($duree);
	$heures = $minutes = $seconde = 0;
        
	if ($duree>3600) {
		$heures = intval(floor($duree/3600));
		$duree -= $heures * 3600;
	}
	if ($duree>60) {
		$minutes = intval(floor($duree/60));
		$duree -= $minutes * 60;
	}
        $seconde = $duree;

	if ($heures>0) {
		$return .= $heures. ':';
	}
	if ($minutes>0) {
		$return .= $minutes. ':';
	} else {
		if ($return) {
                    $return .= '00:';
                } else {
                    $return .= '0:';
                }
        }
	if ($seconde>9) {
		$return .= $seconde;
        } elseif ($seconde>0) {
		$return .= '0'.$seconde;
	} else {
                $return .= '00';
        }
	return $return;
}

function ciwidget_erreur_largeur($largeur){
    $return = '';
    $largeur_int = intval($largeur);
    $largeur_min = intval(ciwidget_lire_meta_cle('commun','largeur_min'));
    $largeur_max = intval(ciwidget_lire_meta_cle('commun','largeur_max'));
    if ($largeur_int>0){
        if ($largeur_int<$largeur_min) {
            $return = _T('ciwidget:valeur_min').' : '.$largeur_min;
        }
        elseif ($largeur_int>$largeur_max) {
            $return = _T('ciwidget:valeur_max').' : '.$largeur_max;
        }
    }

    return $return;
}

function ciwidget_erreur_hauteur($hauteur){
    $return = '';
    $hauteur_int = intval($hauteur);	
    $hauteur_min = intval(ciwidget_lire_meta_cle('commun','hauteur_min'));
    $hauteur_max = intval(ciwidget_lire_meta_cle('commun','hauteur_max'));
    if ($hauteur_int>0){
        if ($hauteur_int<$hauteur_min) {
            $return = _T('ciwidget:valeur_min').' : '.$hauteur_min;
        }
        elseif ($hauteur_int>$hauteur_max) {
            $return = _T('ciwidget:valeur_max').' : '.$hauteur_max;
        }
    }

    return $return;
}


function ciwidget_verif_largeur_sinon_defaut($largeur, $largeur_defaut){
    $largeur_int = intval($largeur);	
    $largeur_min = intval(ciwidget_lire_meta_cle('commun','largeur_min'));
    $largeur_max = intval(ciwidget_lire_meta_cle('commun','largeur_max'));
    if ($largeur_int>0){
        if ($largeur_int<$largeur_min OR $largeur_int>$largeur_max) {
            $largeur_int = intval($largeur_defaut);
        }
    } else {
            $largeur_int = intval($largeur_defaut);
    }

    return strval($largeur_int);
}

function ciwidget_verif_hauteur_sinon_defaut($hauteur, $hauteur_defaut){
    $hauteur_int = intval($hauteur);	
    $hauteur_min = intval(ciwidget_lire_meta_cle('commun','hauteur_min'));
    $hauteur_max = intval(ciwidget_lire_meta_cle('commun','hauteur_max'));
    if ($hauteur_int>0){
        if ($hauteur_int<$hauteur_min OR $hauteur_int>$hauteur_max) {
            $hauteur_int = intval($hauteur_defaut);
        }
    } else {
            $hauteur_int = intval($hauteur_defaut);
    }

    return strval($hauteur_int);
}


function ciwidget_erreur_duree($duree){
    $return = '';
    
    if ($duree=='00:00:00'){
        $return = _T('ciwidget:valeur_incorrecte');
    }
    if (!preg_match('#([0-9]{1,2}):([0-9]{1,2}):([0-9]{1,2})#', $duree, $regs)) {
        $return = _T('ciwidget:valeur_incorrecte');
    }
    if ($regs[1] > 23 or $regs[2] > 59  or $regs[3] > 59) {
        $return = _T('ciwidget:valeur_incorrecte');
    }

    return $return;
}

function ciwidget_retour_formulaire($objet='',$id_objet='',$type_widget='',$retour=''){
    $res = array();
    
    $popin = ciwidget_popin_type_widget($type_widget);
    
    if ($popin=='oui'){
        $libelle = _T('info_modification_enregistree');
        $autoclose = '<script type="text/javascript">if (window.jQuery) jQuery.modalboxclose();</script>';
        $reload = '<script type="text/javascript">if (window.jQuery) ajaxReload("ciwidget");</script>';
        
        if ($retour) {
                $res['redirect'] = $retour;
                $autoclose = '';
                $reload = '';
        } else {
		$res['editable'] = true;
	}
        
        $res['message_ok'] = $libelle . $autoclose . $reload;
        
    } else {
        $res['redirect'] = ciwidget_retour_vers_objet($objet, $id_objet);
    }

    return $res;
}

function ciwidget_retour_vers_objet($objet='',$id_objet='',$retour=''){
    $return = '';
    $self = self();
    $id_objet = intval($id_objet);


    if ($objet AND $id_objet){
        include_spip('inc/urls');
        if (test_espace_prive()){
            $return = html_entity_decode(generer_url_ecrire_objet($objet, $id_objet, '', '', false));
        } elseif (strpos($self,'page=cisf_')>0) {
            // compatibilite avec le plugin CISF
            $return = "spip.php?page=cisf_article&id_article=".$id_objet;
            
            // rechercher la rubrique dans retour (de maniere securisee)
            $id_rubrique = 0;
            if ($retour){
                $tableau_retour = explode('&',str_replace('&amp;','&',$retour));
                foreach ($tableau_retour AS $valeur){
                    if (substr($valeur,0,12)=='id_rubrique='){
                        $id_rubrique = intval(substr($valeur,12));
                        if ($id_rubrique){
                            $return .= "&id_rubrique=".$id_rubrique;
                        }
                        break;
                    }
                }
            }
            // sinon rechercher dans self
            if (!$id_rubrique){
                $tableau_self = explode('&',str_replace('&amp;','&',$self));
                foreach ($tableau_self AS $valeur){
                    if (substr($valeur,0,12)=='id_rubrique='){
                        $id_rubrique = intval(substr($valeur,12));
                        if ($id_rubrique){
                            $return .= "&id_rubrique=".$id_rubrique;
                        }
                        break;
                    }
                }
            }
            
        } else {
            $return = html_entity_decode(generer_url_ecrire_objet($objet, $id_objet, '', '', true));
        }
    }

    return $return;
}

function ciwidget_retour_formulaire_etape($objet='',$id_objet='',$id_widget='',$id_widget_tmp='',$type_widget='',$numform=''){
    $res = array();
    
    include_spip('inc/urls');
    $option = '';
    if ($numform){
        $option .= '&numform='.intval($numform);
    }
    if ($id_widget){
        $option .= '&id_widget='.intval($id_widget);
    }
    if ($id_widget_tmp){
        $option .= '&id_widget_tmp='.intval($id_widget_tmp);
    }
    if (!$id_widget_tmp AND !$id_widget){
        $option .= '&objet='.$objet.'&id_objet='.intval($id_objet).'&type_widget='.$type_widget;
    }
    
    $return = generer_url_ecrire('ciwidget_'.$type_widget.'_edit').$option;
    
    // compatibilite avec le plugin CISF
    // spip.php?page=cisf_widget&type_widget=...&id_article=...&id_rubrique=...
    $self = self();
    if (strpos($self,'page=cisf_')>0) {
        $self = str_replace('&amp;','&',$self);
        $parsed_url = parse_url($self);
      	if ($parsed_url AND isset($parsed_url['query'])) {
            parse_str($parsed_url['query'], $params);
            // laisser id_article, id_rubrique
            $tableau_args = array('numform','id_widget','id_widget_tmp','objet','id_objet','type_widget');
            foreach ($tableau_args AS $arg){
                if (isset($params[$arg])){
                    unset($params[$arg]);
                }
            }
            $new_query = '';
            foreach ($params AS $cle=>$valeur){
                $new_query .= $cle.'='.$valeur.'&';
            }
            $new_query .= 'type_widget='.$type_widget.'&';
            
            if ($new_query){
                $new_query = substr($new_query, 0, -1);
            }
            
            $return = str_replace($parsed_url['query'],$new_query,$self).$option;
	     }
    }
    
    $res['message_ok'] = 'Ok';
    $res['redirect'] = $return;

    return $res;
}

function ciwidget_url_type_widget_edit($type_widget='',$numform='',$id_widget='',$id_widget_tmp=''){
    $return = '';
    
    if ($type_widget){
        include_spip('inc/urls');
        $option = '';
        if ($numform){
            $option .= '&numform='.intval($numform);
        }
        if ($id_widget){
            $option .= '&id_widget='.intval($id_widget);
        }
        if ($id_widget_tmp){
            $option .= '&id_widget_tmp='.intval($id_widget_tmp);
        }
/*        
        if (!$id_widget_tmp AND !$id_widget){
            $option .= '&objet='.$objet.'&id_objet='.intval($id_objet).'&type_widget='.$type_widget;
        }
*/
        $return = generer_url_ecrire('ciwidget_'.$type_widget.'_edit').$option;

        // compatibilite avec le plugin CISF
        // spip.php?page=cisf_widget&type_widget=...&id_article=...&id_rubrique=...
        $self = self();
        if (strpos($self,'page=cisf_')>0) {
            $self = str_replace('&amp;','&',$self);
            $parsed_url = parse_url($self);
            if ($parsed_url AND isset($parsed_url['query'])) {
                parse_str($parsed_url['query'], $params);
                // laisser id_article, id_rubrique
                $tableau_args = array('numform','id_widget','id_widget_tmp','type_widget');
                foreach ($tableau_args AS $arg){
                    if (isset($params[$arg])){
                        unset($params[$arg]);
                    }
                }
                $new_query = '';
                foreach ($params AS $cle=>$valeur){
                    $new_query .= $cle.'='.$valeur.'&';
                }
                $new_query .= 'type_widget='.$type_widget.'&';
                
                if ($new_query){
                    $new_query = substr($new_query, 0, -1);
                }

                $return = str_replace($parsed_url['query'],$new_query,$self).$option;
            }
        }
    }
    
    return $return;
}

function ciwidget_numform(){
    $return = '';
    
    $suivant = _request('suivant');
    if ($suivant){
        $return = intval(_request('form_suivant'));
    }
    $precedent = _request('precedent');
    if ($precedent){
        $return = intval(_request('form_precedent'));
    }
    $modifier = _request('modifier');
    if ($modifier){
        $return = 99;
    }
    
    return $return;
}

function ciwidget_url_widget_edit($objet='',$id_objet='',$type_widget='',$id_widget='',$retour=''){
    $return = $retour;
    
    if ($type_widget AND $objet AND $id_objet){
        $popin = ciwidget_popin_type_widget($type_widget);
        
        if ($retour AND strpos($retour, 'cisf_article')!==false){
            // si saisie via CISF
            $return = generer_url_public('cisf_article', 'id_article='.$id_objet.'&cilienget=bt_widget_modifier-'.$type_widget.'-'.$id_widget);
                
        } elseif ($popin=='non') {
            include_spip('inc/urls');
            $option = '';
            if ($id_widget){
                $option = '&id_widget='.$id_widget;
            }
            $return = generer_url_ecrire('ciwidget_'.$type_widget.'_edit')
                .'&type_widget='.$type_widget
                . $option    
                .'&objet='.$objet
                .'&id_objet='.$id_objet
                .'&retour='.ciwidget_retour_vers_objet($objet,$id_objet);
        }
    }
    
    return $return;
}

function ciwidget_popin_type_widget($id_type=''){
    $return = 'non';

    include_spip('inc/ciwidget_commun');
    $types_widget = ciwidget_types_widget();
    
    foreach ($types_widget AS $cle=>$type_widget) {
        if (isset($type_widget['id']) AND $type_widget['id']==$id_type AND isset($type_widget['popin'])){
            $return = $type_widget['popin'];
        }
    };
    
    return $return;
}



/* RGPD (tarteaucitron) */

function ciwidget_tarteaucitron($type_widget=''){
    $return = false;

    // Ne pas utiliser le RGPD dans l'espace prive
    if (!test_espace_prive() AND ciwidget_lire_meta_cle($type_widget,'rgpd')=='oui'){
          $return = true;
    }

    return $return;
}

function ciwidget_tarteaucitron_actif($type_widget=''){
    $return = 'non';
    
    if (ciwidget_tarteaucitron($type_widget)){
          $return = 'oui';
    }

    return $return;
}

function ciwidget_tarteaucitron_script($type_widget){
    $return = '';
    
    if (defined('_CIWIDGET_RGPD_BANNIERE_SUR_TOUTES_LES_PAGES') AND _CIWIDGET_RGPD_BANNIERE_SUR_TOUTES_LES_PAGES=='oui'){
        return $return;
    }
    
    if (defined('_CIWIDGET_PAS_CHARGER_TARTEAUCITRON') AND _CIWIDGET_PAS_CHARGER_TARTEAUCITRON=='oui'){
        return $return;
    }
    
    if ($type_widget AND ctype_alpha($type_widget) AND ciwidget_service_tarteaucitron($type_widget)){
        $return = "<script type='text/javascript'> (tarteaucitron.job = tarteaucitron.job || []).push('".ciwidget_service_tarteaucitron($type_widget)."'); </script>";
    }
    
    return $return;
}

function ciwidget_service_tarteaucitron($type_widget='') {
    $return = '';
    
    $tableau_correspondance = array(
        'tweet'=>'twitterembed',
        'twitter'=>'twittertimeline',
        'dailymotion'=>'dailymotionrwd',
        'youtube'=>'youtuberwd',
        'slideshare'=>'slideshare',
        'linkedin'=>'linkedinrwd'
    );
    
    if ($type_widget AND isset($tableau_correspondance[$type_widget])){
            $return = $tableau_correspondance[$type_widget];
    }
    
    return $return;
}

function ciwidget_tableau_widgets_tarteaucitron() {
    $return = array();
    
    $types_widget = ciwidget_tableau_id_widgets_concerne_grpd();

    foreach ($types_widget as $widget) {
        if (ciwidget_lire_meta_cle($widget,'rgpd')=='oui'){        
            $return[] = $widget;
        }
    }
    
    return $return;
}

function ciwidget_valeurs_lues_en_base($id_widget=0,$type_widget=''){
    $valeurs = array();
    $id_widget = intval($id_widget);
    
    if ($id_widget>0) {
            $result = sql_select("*", "spip_ciwidget", "id_widget=$id_widget");
            while ($row = sql_fetch($result)) { 
                    $valeurs = $row;
            }

            // anti hack
            if (isset($valeurs['type_widget']) AND $valeurs['type_widget']!=$type_widget){
                return false;
            }

            // unserialize le champ contenu
            if (isset($valeurs['contenu'])){
                $contenu = unserialize($valeurs['contenu']);
                $valeurs['contenu'] = '';
                if ($contenu AND is_array($contenu)){
                    $valeurs = array_merge($valeurs,$contenu);
                }
            }
    }
    
    return $valeurs;
}

function ciwidget_contenu_unserialize($id_widget){
    $return = array();

    $id_widget = intval($id_widget);
    if ($id_widget>0){
            $result = sql_select("contenu", "spip_ciwidget", "id_widget=$id_widget");
            while ($row = sql_fetch($result)) { 
                    $valeurs = $row;
            }

            if (isset($valeurs['contenu'])){
                $return = unserialize($valeurs['contenu']); 
            }
    }

    return $return;
}

function ciwidget_contenu_valeur($id_widget,$item){
    static $tableau_contenu = array();
    
    if (!$tableau_contenu){
        $tableau_contenu = ciwidget_contenu_unserialize($id_widget);
    }
    
    if ($item AND isset($tableau_contenu[$item])){
        return $tableau_contenu[$item];
    } else {
        return '';
    }
}

function ciwidget_purger_cache_css() {
    if (isset($GLOBALS['meta']['auto_compress_css']) AND $GLOBALS['meta']['auto_compress_css']=='oui') {
        // purge UNIQUEMENT du cache des css -> mais effet de bord, aussi ne rien faire
//                    include_spip('inc/invalideur');
//                    purger_repertoire(_DIR_VAR . 'cache-css');
    } else {        
        // purge UNIQUEMENT des fichiers de ciwidget du cache des css
        $dir = _DIR_VAR . 'cache-css';
	if (!is_dir($dir) or !is_readable($dir)) {
		return;
	}
	$handle = opendir($dir);
	if (!$handle) {
		return;
	}

	while (($fichier = @readdir($handle)) !== false) {
		// Eviter ".", "..", ".htaccess", ".svn" etc.
		if ($fichier[0] == '.') {
			continue;
		}
		$chemin = "$dir/$fichier";
                $debut = "cssdyn-_css_ciwidget";
                if (substr($fichier,0,strlen($debut))==$debut){
                    if (is_file($chemin)) {
                            supprimer_fichier($chemin);
                    }
                }
	}
	closedir($handle);
    }
    
    return true;
}

function ciwidget_xtTraiter($nompage) {
        if (empty($nompage)){
            return '';
        }

        $safe = '';
        // passer en minuscule
        $t = strtolower(trim($nompage));
        include_spip('inc/filtres');	
        $t = filtrer_entites($t);

        if ($t) {
                // supprimer les accents
                include_spip('inc/charsets');
                $tsa = translitteration($t);

                // Les caracteres autorises par XITI sont les suivants :
                // - les lettres abcdefghijklmnopqrstuvwxyz en majuscules ou minuscules
        // - les chiffres 123467890
                // - les points, les slashs, les moins, les underscores, les tildes
                // ajout des deux points pour compatibilite ascendante
                $tableau = array('.','/','-','_','~',':');
                $tscs = str_replace($tableau,'',$tsa);		
                if (!ctype_alnum($tscs)) {
                        // enlever les caracteres speciaux (sauf ceux qui sont autorises)
                        $longueur = strlen($tsa);
                    for ($i = 0; $i < $longueur; $i++){
                        if (ctype_alnum($tsa[$i]) OR in_array($tsa[$i], $tableau))
                                $safe .= $tsa[$i];
                        else
                                $safe .= ' ';
                    }
                } else {
                        $safe = $tsa;
                }

            // remplacer les espaces par des underscores
            $nompage = str_replace(' ','_',$safe);		
        }
     
    return $nompage;
}

// Si XITI, recuper le contenu de l'attribut s2 (dans l'URL d'abonnement)
function ciwidget_xtn2($var=''){
    $return = '';

    if (defined('_DIR_PLUGIN_CIPARAM')){
        if ($ci_abonnement_xiti = ciparam_lire_meta('ci_abonnement_xiti')) {
                if (strpos($ci_abonnement_xiti,'_images/void.gif')===false){
                        $pos = strpos($ci_abonnement_xiti,'s2=');
                        if ($pos!==false){
                                $return = substr($ci_abonnement_xiti,$pos+3);
                                $pos2 = strpos($return,'&');
                                if ($pos2!==false)
                                        $return = substr($return,0,$pos2-1);

                        }
                }
        }
    }
    return $return;
}

function ciwidget_gis_typecarte(){
    return array(
        'point_libre'=>array('objets'=>'point_libre', 'id_critere'=>''),
        'objet'=>array('objets'=>'objet', 'id_critere'=>''),
        'articles_mot'=>array('objets'=>'articles', 'id_critere'=>'id_mot'),
        'articles_rubrique'=>array('objets'=>'articles', 'id_critere'=>'id_rubrique'),
        'articles_branche'=>array('objets'=>'articles_branche', 'id_critere'=>'id_rubrique'),
        'articles'=>array('objets'=>'articles', 'id_critere'=>'')
        );
}


function ci_niveau_titre($type_widget){
    return ciwidget_lire_meta_cle($type_widget,'titre_niveau_titre');
}

function ci_niveau_titreitem($type_widget){
    return ciwidget_lire_meta_cle($type_widget,'titreitem_niveau_titre');
}

function ciwidget_extraire_src($code=''){
    $return = '';
    
    if (preg_match('/src="([^"]+)"/', $code, $match) OR preg_match("/src='([^']+)'/", $code, $match)){
        if (isset($match[1])){
            $return = html_entity_decode($match[1]);
        }
    }
    
    return $return;
}

function ciwidget_extraire_style($code=''){
    $return = '';
    
    if (preg_match('/style="([^"]+)"/', $code, $match) OR preg_match("/style='([^']+)'/", $code, $match)){
        if (isset($match[1])){
            $return = $match[1];
        }
    }
    
    return $return;
}

function ciwidget_extraire_src_iframe_ou_url($code=''){
    $return = '';
    $code = str_replace('<IFRAME','<iframe',$code);
    $code = str_replace('SRC=','src=',$code);
    
    if (strpos($code, '<iframe') !== false AND strpos($code, 'src=') !== false) {
        $return = ciwidget_extraire_src($code);
    } else {
        $return = $code;
    }
    
    return $return;
}

function ciwidget_extraire_style_iframe($code=''){
    $return = '';
    $code = str_replace('<IFRAME','<iframe',$code);

    if (strpos($code, '<iframe') !== false) {
        $tableau = explode('<iframe',$code);

        if (isset($tableau[1])) {
            $return = ciwidget_extraire_style($tableau[1]);
        }
    }
    return $return;
}

function ciwidget_extraire_style_div_avant_iframe($code=''){
    $return = '';
    $code = str_replace('<IFRAME','<iframe',$code);

    if (strpos($code, '<iframe') !== false) {
        $tableau = explode('<iframe',$code);

        if (isset($tableau[0])) {
            $return = ciwidget_extraire_style($tableau[0]);
        }
    }
    return $return;
}

function ciwidget_verifier_url_dans_liste_blanche($url='',$liste_blanche=''){
    $ci_dans_liste = false;
    $ci_host = '';
    
    if (!tester_url_absolue($url)) {
        return true;
    }

    $array = parse_url($url);
    if (isset($array["host"])){
        $ci_host = strtolower($array["host"]);    
    }
    
    $safe = str_replace(array("'",'"',CHR(10),CHR(13),' '),'',$liste_blanche);
    $safe = trim($safe);
    if (substr($safe,-1)==','){
        $safe = substr($safe,0,-1);
    }
    $safe = strtolower($safe);
    
    $tableau_liste_blanche = explode(',',$safe);

    // le HOST est-il dans la liste ?
    if ($ci_host){
            foreach ($tableau_liste_blanche as $host_blanc) {
                    // HOST se terminant par ...
                    if (substr($host_blanc,0,1)=='.') {
                            if ($host_blanc==substr($ci_host,-strlen($host_blanc))){
                                    $ci_dans_liste = true;
                                    break;
                            }
                    } else {
                            if ($host_blanc==$ci_host){
                                    $ci_dans_liste = true;
                                    break;
                            }
                    }
            }
    }
    
    return $ci_dans_liste;
}

function ciwidget_url_identifier_widget_dedie($url=''){
    $return = '';

    include_spip('inc/video_commun');

    // verifier par rapport aux widgets dedies
    if($url){
        if (ci_dailymotion_fichier($url)) {
                $return = 'dailymotion';
        } elseif (ci_youtube_fichier($url)) {
                $return = 'youtube';
        } elseif (ci_streamhls_url($url)) {
                $return = 'streamhls';
        } elseif (stripos($url,'slideshare.net')!==false) {
                $return = 'slideshare';
        } elseif (stripos($url,'terra.developpement-durable.gouv.fr')!==false) {
                $return = 'terra';
        }
    }
    
    return $return;
}

function ciwidget_utiliser_bigup($arg='') {
    $cibigup = '';

    if (defined('_DIR_PLUGIN_BIGUP')){
        $cibigup = 'oui';
        
        if (!defined('_CI_FORCER_UTILISER_BIGUP') OR strtolower(_CI_FORCER_UTILISER_BIGUP)!='oui'){
            $cibigup = 'oui';
            ciwidget_ecrire_preferences_bigup();

            if (isset($GLOBALS['visiteur_session']['prefs']['ci_bigup']) AND $GLOBALS['visiteur_session']['prefs']['ci_bigup']=='non'){
                $cibigup = '';
            }
        }
    }
    
    return $cibigup;
}

function ciwidget_ecrire_preferences_bigup() {
    static $done = false;
    $ci_bigup_actuel = '';
    $ci_bigup_nouveau = '';

    if (!$done) {
        $done = true;
    
        if (intval($GLOBALS['visiteur_session']['id_auteur'])) {

            // preference actuelle
            if (isset($GLOBALS['visiteur_session']['prefs']['ci_bigup'])){
                $ci_bigup_actuel = $GLOBALS['visiteur_session']['prefs']['ci_bigup'];
            }

            // nouvelle preference
            if ($ci_req_bigup = _request('ci_bigup')) {
                if (in_array($ci_req_bigup,array('oui','non'))) {
                    if ($ci_req_bigup=='oui' AND $ci_bigup_actuel=='non'){
                        $ci_bigup_nouveau = 'oui';
                    }
                    if ($ci_req_bigup=='non' AND $ci_bigup_actuel!='non'){
                        $ci_bigup_nouveau = 'non';
                    }
                }
            }

            if ($ci_bigup_nouveau){
                include_spip('action/editer_auteur');
                $GLOBALS['visiteur_session']['prefs']['ci_bigup'] = $ci_bigup_nouveau;
                $c = array('prefs' => serialize($GLOBALS['visiteur_session']['prefs']));

                auteur_modifier($GLOBALS['visiteur_session']['id_auteur'], $c);
            }
        }
    }

    return true;
}

function ciwidget_choix_utiliser_bigup($arg='') {
    $cibigup = '';

    if (defined('_DIR_PLUGIN_BIGUP')){
        $cibigup = 'oui';
    }
    
    return $cibigup;
}

function ciwidget_parametre_bigup($url='') {

    if (ciwidget_utiliser_bigup()){
        $url = str_replace('type_widget=','ci_bigup=non&type_widget=',$url);
    } else {
        $url = str_replace('type_widget=','ci_bigup=oui&type_widget=',$url);
    }
    
    return $url;
}

function ciwidget_lien_ancien_upload($arg='') {
    $return = '';

    if (defined('_DIR_PLUGIN_BIGUP')){
        if (!defined('_CI_FORCER_UTILISER_BIGUP') OR strtolower(_CI_FORCER_UTILISER_BIGUP)!='oui'){
            if (ciwidget_utiliser_bigup()){
               $return = '<div class="choix_utiliser_bigup"><a href="'.ciwidget_parametre_bigup(self()).'">'._T('ciwidget:ne_pas_utiliser_bigup').'</a></div>';
            } else {
               $return = '<div class="choix_utiliser_bigup"><a href="'.ciwidget_parametre_bigup(self()).'">'._T('ciwidget:utiliser_bigup').'</a></div>';
            }
        }
    }
    
    return $return;
}

?>